@@ -98,7 +98,9 @@ class FieldAxisymmetric(Field):
         # w.r.t. undeformed coordinate "J" evaluated at quadrature point "p"
         # for each cell "e"
         g = np.einsum(
-            "ca...,aJpc->...Jpc", self.values[self.region.mesh.cells], self.region.dhdX,
+            "ca...,aJpc->...Jpc",
+            self.values[self.region.mesh.cells],
+            self.region.dhdX,
         )
 
         if sym:
